<?php
	/*
	* 2018 - VEGA Informatique
	*
	* NOTICE OF LICENSE
	*
	* This source file is subject to the Open Software License (OSL 3.0)
	* that is bundled with this package in the file LICENSE.txt.
	* It is also available through the world-wide-web at this URL:
	* http://opensource.org/licenses/osl-3.0.php
	*
	* DISCLAIMER
	*
	* Do not edit or add to this file if you wish to upgrade PolarisLink to newer
	* versions in the future. 
	*
	*  @author VEGA Informatique <contact@vega-info.fr>
	*  @copyright  2018 VEGA Informatique
	*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
	*/
	
	function checkString($txt, $regex, $maxSize)
	{
		if (empty($txt))
			return $txt;
		
		$txt = mb_eregi_replace(Tools::cleanNonUnicodeSupport('['.$regex.']*'), "", $txt);	
		
		if (strlen($txt) > $maxSize)
			$txt = mb_strimwidth($txt, 0, $maxSize);
		
		if (empty($txt))
			return "inconnu";
		
		return $txt;
	}
	
	function checkPrice($price, $checkNegative = true)
	{
		if ($price < 0 && $checkNegative)
			return 0;
		return (double) round($price, 6);
	}
	
	function checkProductRef($txt)
	{
		return checkString($txt, '<>;={}', 32);
	}
	
	function checkDescription($txt)
	{
		return str_replace("\n", "<br>", $txt);
	}
	
	function checkMetaDescription($txt)
	{
		$txt = checkString($txt, '<>;={}', 255);
		if (empty($txt))
			$txt = "";
		return $txt;
	}

	function checkVoucherName($txt)
	{
		$txt = checkString($txt, '<>;=#{}', 128);
		if (empty($txt))
			$txt = "Coupon de réduction";
		return $txt;
	}

	function buildLinkRewrite($txt)
	{
		return trim(Tools::link_rewrite($txt));
	}
	
	function checkProductName($txt)
	{
		if (is_array($txt))
		{
			foreach ($txt as $k => $v)
				$txt[$k] = checkProductName($v);			
			
			return $txt;
		}
		else
		{
			$txt = checkString($txt, '<>;=#{}', 128);
			if (empty($txt))
				$txt = "Produit sans nom";
			return $txt;
		}
	}
	
	function checkAttributeName($txt)
	{
		if (is_array($txt))
		{
			foreach ($txt as $k => $v)
				$txt[$k] = checkAttributeName($v);			
			
			return $txt;
		}
		else
			return checkString($txt, '<>;=#{}', 128);
	}

	function checkFeatureName($txt)
	{
		if (is_array($txt))
		{
			foreach ($txt as $k => $v)
				$txt[$k] = checkAttributeName($v);			
			
			return $txt;
		}
		else
			return checkString($txt, '<>;=#{}', 128);
	}
	
	function checkCategoryName($txt)
	{
		if (is_array($txt))
		{
			foreach ($txt as $k => $v)
				$txt[$k] = checkCategoryName($v);			
			
			return $txt;
		}
		else
		{
			$txt = checkString($txt, '<>;=#{}', 128);
			if (empty($txt))
				$txt = "Catégorie sans nom";
			return $txt;
		}
	}
	
	function checkCustomerLastName($txt)
	{
		$txt = trim(str_replace('.', '. ', str_replace('. ', '.', $txt)));	// Bug PS qui ne supporte les points qu'à la condition d'avoir un espace après !!!
		return checkString($txt, '0-9!<>,;?=+()\/\\@#"°*`{}_^$%:¤\[\]', 32);
	}
	
	function checkCustomerFirstname($txt)
	{
		$txt = trim(str_replace('.', '. ', str_replace('. ', '.', $txt)));	// Bug PS qui ne supporte les points qu'à la condition d'avoir un espace après !!!
		return checkString($txt, '0-9!<>,;?=+()\/\\@#"°*`{}_^$%:¤\[\]', 32);
	}
	
	function checkEAN13($ean13)
	{
		if (strlen($ean13) > 13 || !ctype_digit($ean13))
			return "";
		return $ean13;
	}